FoldStyle

Enum FoldStyle 

#[non_exhaustive]
pub enum FoldStyle { Auto, Fixed, None, }
Controls how long strings are folded across lines using / continuation markers.

  • Auto (default): prefer folding immediately after EOL characters, and at whitespace to word boundaries to fit wrap_width.
  • Fixed: fold right at, or if it violates specification (e.g. not between two data characters), immediately before, wrap_width.
  • None: do not fold, even if it means overflowing past wrap_width.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Auto

Prefer folding immediately after EOL characters, and at whitespace to word boundaries to fit wrap_width.



Fixed

Fold right at, or if it violates specification (e.g. not between two data characters), immediately before, wrap_width.



None

Do not fold, even if it means overflowing past wrap_width.