#[non_exhaustive]pub enum IndentGlyphStyle {
Auto,
Fixed,
None,
}Expand description
Controls when /< / /> indent-offset glyphs are emitted to push content to visual indent 0.
Auto(default): apply glyphs when content would overflowwrap_widthat its natural indent, or when the indent depth exceeds half ofwrap_width.Fixed: always apply glyphs once the indent depth exceeds a threshold, without waiting for overflow.None: never apply glyphs; content may overflowwrap_width.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auto
Apply glyphs reactively on overflow, or proactively at half of wrap_width.
Fixed
Always apply glyphs past a fixed indent threshold, regardless of overflow.
None
Never apply indent-offset glyphs.