StringArrayStyle

Enum StringArrayStyle 

#[non_exhaustive]
pub enum StringArrayStyle { Spaces, PreferSpaces, Comma, PreferComma, None, }
Controls how arrays of short strings are packed onto a single line.

  • Spaces: always separate with spaces (e.g. [ a b c).
  • PreferSpaces: use spaces when it fits, fall back to block layout.
  • Comma: always separate with commas (e.g. [ a, b, c).
  • PreferComma (default): use commas when it fits, fall back to block layout.
  • None: never pack string arrays onto one line.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Spaces



PreferSpaces



Comma



PreferComma



None